# gPRC for MEC010-2

The ETSI MEC ISG Application Life Cycle Management API described using OpenAPI.

## Overview
These files were generated by the [OpenAPI Generator](https://openapi-generator.tech) project.

- API version: 3.1.1
- Package version: 
- Build package: org.openapitools.codegen.languages.ProtobufSchemaCodegen
For more information, please visit [https://forge.etsi.org/rep/mec/gs010-2-app-pkg-lcm-api](https://forge.etsi.org/rep/mec/gs010-2-app-pkg-lcm-api)

## Usage

Below are some usage examples for Go and Ruby. For other languages, please refer to https://grpc.io/docs/quickstart/.

### Python

1. Install the grpcio-tools package
    ```sh
    $ pip install grpcio-tools
    ```

2. Create a directory for generated Python stubs
    ```sh
    $ mkdir python-stubs 
    ```

3. Run the following command from the root of the directory containing this README that you are reading.

   - Models:
  
        ```sh
        $ python -m grpc_tools.protoc -I./AppLcmProto3/proto3 --python_out=./python-stubs ./AppLcmProto3/proto3/models/*
        ```
    
        The above command will generate .py files for all the data models in the ./models directory

   - Services:

        ```sh
        $ python -m grpc_tools.protoc -I./AppLcmProto3/proto3 --python_out=./python-stubs --grpc_python_out=./python-stubs ./AppLcmProto3/proto3/services/*
        ```

        The above command will generate service files for the App LCM API, containing:
        - Python data models used in the App LCM API
        - Classes and functions needed for the supported HTTP methods in the App LCM API

### Go

1. Install protocol buffer compiler
    ```sh
    $ apt install -y protobuf-compiler
    ```
2. Install Go plugins for `protoc`
    ```sh
    $ go install google.golang.org/protobuf/cmd/protoc-gen-go@v1.28.1
    ```
    ```sh
    $ go install google.golang.org/grpc/cmd/protoc-gen-go-grpc@v1.2.0
    ```
3. Update `PATH` so `protoc` can find the plugins
    ```sh
    $ export PATH="$PATH:$(go env GOPATH)/bin"
    ```
4. Define a go package by appending `option go_package = "./mec0102.services.applcmservice";` in .proto files like this:

    ```Go
    syntax = "proto3";

    package mec0102.services.applcmservice;

    option go_package = "./mec0102.services.applcmservice";

    import public "models/<xyz>.proto";
    ```

5. Generate Go code for models and services
    ```sh 
    $ mkdir go-stubs

    $ protoc --go_out=./go-stubs ./AppLcmProto3/proto3/models/* -I./AppLcmProto3/proto3
    
    $ protoc --go_out=./go-stubs ./AppLcmProto3/proto3/services/* --go-grpc_out=go-stubs -I./AppLcmProto3/proto3
    ```


    > The generated `<data_model>.pb.go` files will contain all the protocol buffer code to populate, serialize, and retrieve request and response message types defined in the `models` folder.

    > The `<xyz_grpc>.pb.go` file will contain the stubs for the methods defined in the `<xyz_service>.proto` file.

### Ruby

1. Install gRPC Ruby Plugin and required tools
   ```sh
   $ gem install grpc
   $ sudo apt install ruby-grpc-tools
   ```

2. Generate code
    ```sh
    $ mkdir ruby-stubs
    ```
    
    Run the following command to create Ruby modules for all the data models defined in the proto files.

    ```sh
    $ grpc_tools_ruby_protoc -I./AppLcmProto3/proto3 --ruby_out=ruby-stubs ./AppLcmProto3/proto3/models/*
    ```
    
    Run the following command to generate services files, containing stub and service classes for the endpoints and methods defined in App LCM API.

    ```sh
    $ grpc_tools_ruby_protoc -I./AppLcmProto3/proto3 --ruby_out=ruby-stubs --grpc_out=ruby-stubs ./AppLcmProto3/proto3/services/*
    ```